@@ -5,5 +5,7 @@
 assign("ll_warn", FALSE, envir = .spOptions)
 assign("ll_TOL", 0.25, envir = .spOptions)
 assign("ReplCRS_warn", TRUE, envir = .spOptions)
+assign("Polypath", TRUE, envir = .spOptions)
+assign("PolypathRule", "winding", envir = .spOptions)
 .onUnload <- function(libpath)
     library.dynam.unload("sp", libpath)
